translate.convert.po2ini

Package translate :: Package convert :: Module po2ini |
[hide private]
[frames] | no frames]

# Source Code for Module translate.convert.po2ini

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2002-2006 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22
    23  """convert Gettext PO localization files to .ini files"""
    24
    25  from translate.storage import factory
    26
    27 -class reini:
    28 -    def __init__(self, templatefile, dialect):
    29          from translate.storage import ini
    30          self.templatefile = templatefile
    31          self.templatestore = ini.inifile(templatefile, dialect=dialect)
    32          self.inputdict = {}
    33
    34 -    def convertstore(self, inputstore, includefuzzy=False):
    35          self.makestoredict(inputstore, includefuzzy)
    36          for unit in self.templatestore.units:
    37              for location in unit.getlocations():
    38                  unit.target = self.inputdict[location]
    39          return str(self.templatestore)
    40
    41 -    def makestoredict(self, store, includefuzzy=False):
    42          # make a dictionary of the translations
    43          for unit in store.units:
    44              if includefuzzy or not unit.isfuzzy():
    45                  # there may be more than one entity due to msguniq merge
    46                  for location in unit.getlocations():
    47                      inistring = unit.target
    48                      if len(inistring.strip()) == 0:
    49                          inistring = unit.source
    50                      self.inputdict[location] = inistring
    51
    52 -def convertini(inputfile, outputfile, templatefile, includefuzzy=False, dialect="default"):
    53      inputstore = factory.getobject(inputfile)
    54      if templatefile is None:
    55          raise ValueError("must have template file for ini files")
    56      else:
    57          convertor = reini(templatefile, dialect)
    58      outputstring = convertor.convertstore(inputstore, includefuzzy)
    59      outputfile.write(outputstring)
    60      return 1
    61
    62 -def convertisl(inputfile, outputfile, templatefile, includefuzzy=False, dialect="inno"):
    63      convertini(inputfile, outputfile, templatefile, includefuzzy, dialect)
    64
    65 -def main(argv=None):
    66      # handle command line options
    67      from translate.convert import convert
    68      formats = {
    69                 ("po", "ini"): ("ini", convertini),
    70                 ("po", "isl"): ("isl", convertisl),
    71                }
    72      parser = convert.ConvertOptionParser(formats, usetemplates=True, description=__doc__)
    73      parser.add_fuzzy_option()
    74      parser.run(argv)
    75
    76  if __name__ == '__main__':
    77      main()
    78